@@ -1,6 +1,6 @@
 from typing_extensions import Annotated, TypedDict
 
-from patchwork.common.utils.types import IS_CONFIG
+from patchwork.common.utils.typing import IS_CONFIG
 
 
 class GenerateCodeRepositoryEmbeddingsInputs(TypedDict, total=False):
