@@ -35,6 +35,7 @@ from patchwork.steps.ScanDepscan.ScanDepscan import ScanDepscan
 from patchwork.steps.ScanSemgrep.ScanSemgrep import ScanSemgrep
 from patchwork.steps.SimplifiedLLM.SimplifiedLLM import SimplifiedLLM
 from patchwork.steps.SlackMessage.SlackMessage import SlackMessage
+from patchwork.steps.JoinList.JoinList import JoinList
 
 __all__ = [
     "AnalyzeImpact",
@@ -66,4 +67,5 @@ __all__ = [
     "ScanSemgrep",
     "SimplifiedLLM",
     "SlackMessage",
+    "JoinList"
 ]
